"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.register = exports.logout = exports.checkToken = exports.login = void 0;
const bcrypt = require("bcryptjs");
const jwt = require("jsonwebtoken");
const dataWithoutPassword_1 = require("../utils/dataWithoutPassword");
const student_record_1 = require("../records/student.record");
const checkMailAvailable_1 = require("../utils/checkMailAvailable");
const errors_1 = require("../utils/errors");
const user_record_1 = require("../records/user.record");
const login = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const { email, password } = req.body;
        const user = yield user_record_1.UserRecord.getUserByEmail(email);
        if (!user) {
            return res.status(401).json({ message: 'Invalid credentials' });
        }
        if (user) {
            const passwordMatch = yield bcrypt.compare(password, user.password);
            if (passwordMatch) {
                const token = jwt.sign({ id: user.id, role: user.role }, process.env.JWT, { expiresIn: '1h' });
                res
                    .cookie("access_token", token, { httpOnly: true })
                    .status(200)
                    .json({
                    user: (0, dataWithoutPassword_1.userWithoutPassword)(user),
                    token,
                });
            }
            else {
                return res.status(401).json({ message: 'Invalid credentials' });
            }
        }
    }
    catch (err) {
        next(err);
    }
});
exports.login = login;
const checkToken = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    const token = (_a = req.header('Authorization')) === null || _a === void 0 ? void 0 : _a.slice(7);
    if (token) {
        try {
            const decoded = jwt.verify(token, process.env.JWT);
            if (typeof decoded === 'object' && 'id' in decoded && 'role' in decoded) {
                const id = decoded.id;
                const role = decoded.role;
                const user = yield user_record_1.UserRecord.getUserById(id);
                if (user) {
                    const clearedUser = (0, dataWithoutPassword_1.userWithoutPassword)(user);
                    return res.status(200).json(Object.assign({ id, role }, clearedUser));
                }
            }
            else {
                console.error('Invalid token format');
            }
        }
        catch (err) {
            console.error('Token verification failed:', err);
        }
    }
    return res.status(401).json({ error: 'Unauthorized' });
});
exports.checkToken = checkToken;
const logout = (req, res, next) => {
    res.status(200).json({ message: 'Logged out successfully' });
};
exports.logout = logout;
const register = (req, res, next) => __awaiter(void 0, void 0, void 0, function* () {
    const { email, password } = req.body;
    const hashedPassword = yield bcrypt.hash(password, 10);
    const checkOkMail = yield (0, checkMailAvailable_1.checkMailAvailable)(email); //sprawdzanie dostępności maila
    if (!checkOkMail) {
        throw new errors_1.ValidationError("Email already exists.");
    }
    //@todo MAIL INFO TO USER
    const userData = Object.assign(Object.assign({}, req.body), { password: hashedPassword });
    const user = yield new student_record_1.StudentRecord(userData);
    yield user.insert();
    res.status(200).json('User has been created');
});
exports.register = register;
//# sourceMappingURL=auth.js.map