"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const express = require("express");
const cors = require("cors");
require("express-async-errors");
const cookieParser = require("cookie-parser");
require('dotenv').config();
const errors_1 = require("./utils/errors");
require("./utils/db"); //połączenie z bazą danych
//routers
const course_1 = require("./routers/course");
const teacher_1 = require("./routers/teacher");
const student_1 = require("./routers/student");
const auth_1 = require("./routers/auth");
const admin_1 = require("./routers/admin");
const shop_1 = require("./routers/shop");
const dato_1 = require("./routers/dato");
const rateCourse_1 = require("./routers/rateCourse");
const app = express();
const corsOptions = {
    origin: ['http://localhost:5173', 'http://localhost:3000', 'https://menager.networkmanager.pl'],
};
//middlewares
app.use(cors(corsOptions));
//app.use(limiter)
app.use(express.urlencoded({ extended: true }));
app.use(express.json());
app.use(cookieParser());
app.use('/api/course', course_1.courseRouter);
app.use('/api/teacher', teacher_1.teacherRouter);
app.use('/api/student', student_1.studentRouter);
app.use('/api/auth', auth_1.authRouter);
app.use('/api/admin', admin_1.adminRouter);
app.use('/api/shop', shop_1.shopRouter);
app.use('/api/rate-course', rateCourse_1.rateCourseRouter);
app.use('/api/dato', dato_1.datoRouter);
app.use(errors_1.handleError);
app.listen(3001, '0.0.0.0', () => {
    console.log('Listening on http://localhost:3001');
});
//# sourceMappingURL=index.js.map