"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CourseRecord = void 0;
const db_1 = require("../utils/db");
const errors_1 = require("../utils/errors");
const uuid_1 = require("uuid");
class CourseRecord {
    constructor(obj) {
        if (!obj.name || obj.name.length < 4 || obj.name.length > 40) {
            throw new errors_1.ValidationError('Courses name should contain from 4 to 40 characters');
        }
        if (obj.description && obj.description.length > 3000) {
            throw new errors_1.ValidationError('Courses description should contain less than 3000 chars.');
        }
        if (!obj.price || obj.price > 99999 || obj.price === 0 || typeof obj.price === 'string') {
            throw new errors_1.ValidationError('Price must be a number, must be bigger than 0 and smaller than 99999.');
        }
        this.id = obj.id;
        this.name = obj.name;
        this.price = obj.price;
        this.description = obj.description;
        this.teacher_id = obj.teacher_id;
        this.photoUrl = obj.photoUrl;
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            if (!this.teacher_id) {
                this.teacher_id = null;
            }
            if (!this.description) {
                this.description = null;
            }
            yield db_1.pool.execute("INSERT INTO `courses`(`id`, `name`, `teacher_id`, `description`,  `price`, `photoUrl`) VALUES(:id, :name, :teacher_id, :description, :price, :photoUrl)", {
                id: this.id,
                name: this.name,
                teacher_id: this.teacher_id !== undefined ? this.teacher_id : null,
                description: this.description !== undefined ? this.description : null,
                price: this.price,
                photoUrl: this.photoUrl,
            });
            return this.id;
        });
    }
    //akutalizacja tabeli relacyjnej
    _updateRelationCoursesTeachers(teacher_id) {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("INSERT INTO `courses_teachers`(`id`,`course_id`, `teacher_id`, `description`) VALUES(:id, :course_id, :description, :teacher_id)", {
                id: (0, uuid_1.v4)(),
                course_id: this.id,
                teacher_id: teacher_id,
                description: this.description,
            });
        });
    }
    static listAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `courses`");
            return results.map(obj => new CourseRecord(obj));
        });
    }
    static listAllCoursesAvailable() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const [results] = yield db_1.pool.execute("SELECT * FROM `courses`");
                const filteredCourses = yield Promise.all(results.map((obj) => __awaiter(this, void 0, void 0, function* () {
                    const course = yield new CourseRecord(obj);
                    const count = yield course.countStudents();
                    if (count < 10) {
                        return {
                            course,
                            count,
                        };
                    }
                })));
                console.log(filteredCourses);
                return filteredCourses;
            }
            catch (error) {
                console.error(error);
                throw error;
            }
        });
    }
    static listCoursesWithoutChosenTeacher() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `courses` ");
            return results
                .map(obj => new CourseRecord(obj))
                .filter(course => course.teacher_id === null);
        });
    }
    static getOne(id) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = (yield db_1.pool.execute("SELECT * FROM `courses` WHERE `id` = :id", {
                id,
            }));
            return results.length === 0 ? null : new CourseRecord(results[0]);
        });
    }
    static listCoursesWithAllData() {
        return __awaiter(this, void 0, void 0, function* () {
            const allCourses = yield CourseRecord.listAll();
            allCourses.map(course => {
                const teacherName = course.teacher_id === null ? null : course.getTeacherName(course.teacher_id);
                const countStudents = course.countStudents();
                const rateCourse = course.getCourseRate(course.id);
            });
        });
    }
    getCourseRate(course_id) {
        return __awaiter(this, void 0, void 0, function* () {
        });
    }
    delete() {
        return __awaiter(this, void 0, void 0, function* () {
            if ((yield this.countStudents()) > 0) {
                throw new errors_1.ValidationError('Cannot delete the course. Remove students assigned to this course first.');
            }
            yield db_1.pool.execute("DELETE FROM `courses` WHERE `id` = :id ", {
                id: this.id,
            });
            //AKTUALIZCJA TABEL RELACYJNYCH
            if (this.teacher_id !== null) {
                yield db_1.pool.execute("DELETE FROM `courses_teachers` WHERE `course_id` = :id", {
                    id: this.id
                });
            }
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `courses` SET `name` = :name, `teacher_id` = :teacher_id, `description` = :description, `price` = :price, `photoUrl` = :photoUrl WHERE `id` = :id", {
                id: this.id,
                name: this.name,
                teacher_id: this.teacher_id,
                description: this.description,
                photoUrl: this.photoUrl,
                price: this.price,
            });
            yield db_1.pool.execute("DELETE FROM `courses_teachers` WHERE `course_id` = :course_id", {
                course_id: this.id
            });
            if (this.teacher_id !== null) {
                yield db_1.pool.execute("UPDATE `courses_teachers` SET  `teacher_id` = :teacher_id WHERE `course_id` = :course_id", {
                    course_id: this.id,
                    teacher_id: this.teacher_id,
                });
            }
        });
    }
    //POBRANIE LICZBY STUDENTÓW DANEGO KURSU
    countStudents() {
        return __awaiter(this, void 0, void 0, function* () {
            const data = yield db_1.pool.execute("SELECT COUNT(*) AS `countStudents` FROM `courses_students` WHERE `course_id` = :id", {
                id: this.id,
            });
            const { countStudents } = data[0][0];
            return countStudents;
        });
    }
    getTeacherName(teacher_id) {
        return __awaiter(this, void 0, void 0, function* () {
            const data = yield db_1.pool.execute("SELECT  `name`, `last_name` FROM `teachers` WHERE `id` = :teacher_id", {
                teacher_id,
            });
            const { name, last_name } = data[0][0];
            return String(`${name} ${last_name}`);
        });
    }
}
exports.CourseRecord = CourseRecord;
//# sourceMappingURL=course.record.js.map