"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RateCourseRecord = void 0;
const errors_1 = require("../utils/errors");
const uuid_1 = require("uuid");
const db_1 = require("../utils/db");
class RateCourseRecord {
    constructor(obj) {
        if (!obj.stars || obj.opinion !== null && obj.opinion.length > 2000) {
            throw new errors_1.ValidationError('Missing data or data not correct.');
        }
        this.id = obj.id;
        this.course_id = obj.course_id;
        this.student_id = obj.student_id;
        this.opinion = obj.opinion;
        this.stars = obj.stars;
    }
    insert() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.id) {
                this.id = (0, uuid_1.v4)();
            }
            if (!this.opinion) {
                this.opinion = null;
            }
            yield db_1.pool.execute("INSERT INTO `course_student_rates`(`id`, `course_id`, `student_id`, `stars`, `opinion`) VALUES(:id, :course_id, :student_id, :stars, :opinion)", {
                id: this.id,
                course_id: this.course_id,
                student_id: this.student_id,
                stars: this.stars,
                opinion: this.opinion,
            });
            return this.id;
        });
    }
    update() {
        return __awaiter(this, void 0, void 0, function* () {
            yield db_1.pool.execute("UPDATE `course_student_rates` SET `stars` = :stars, `opinion` = :opinion `id` = :id", {
                id: this.id,
            });
        });
    }
    static listAll() {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `course_student_rates`");
            return results.map(obj => new RateCourseRecord(obj));
        });
    }
    static listAllForOneCourse(courseId) {
        return __awaiter(this, void 0, void 0, function* () {
            const [results] = yield db_1.pool.execute("SELECT * FROM `course_student_rates`  WHERE `course_id` = :course_id ", {
                course_id: courseId
            });
            return results.map((obj) => new RateCourseRecord(obj));
        });
    }
}
exports.RateCourseRecord = RateCourseRecord;
//# sourceMappingURL=rateCourse.record.js.map