"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.verifyAdmin = exports.verifyUser = exports.verifyToken = void 0;
const jwt = require("jsonwebtoken");
const errors_1 = require("./errors");
const verifyToken = (req, res, next) => {
    const token = req.cookies.access_token;
    if (!token) {
        return next(new errors_1.NotAuthorizedError('You are not authenticated!'));
    }
    try {
        req.user = jwt.verify(token, process.env.JWT);
        next();
    }
    catch (err) {
        if (err instanceof jwt.JsonWebTokenError) {
            return next(new errors_1.ForbiddenError('Forbidden. Token not valid.'));
        }
        else {
            return next(err);
        }
    }
};
exports.verifyToken = verifyToken;
const verifyUser = (req, res, next) => {
    (0, exports.verifyToken)(req, res, () => {
        var _a, _b;
        const id = (_a = req.user) === null || _a === void 0 ? void 0 : _a.id;
        const role = (_b = req.user) === null || _b === void 0 ? void 0 : _b.role;
        if (!id || !role) {
            return next(new errors_1.ForbiddenError('You are not authorized!'));
        }
        if (req.user.id === req.params.id || req.user.role === 'admin') {
            next();
        }
        else {
            return next(new errors_1.ForbiddenError('You are not authorized!'));
        }
    });
};
exports.verifyUser = verifyUser;
const verifyAdmin = (req, res, next) => {
    (0, exports.verifyToken)(req, res, () => {
        var _a, _b, _c;
        const id = (_a = req.user) === null || _a === void 0 ? void 0 : _a.id;
        const role = (_b = req.user) === null || _b === void 0 ? void 0 : _b.role;
        if (!id || !role) {
            return next(new errors_1.ForbiddenError('You are not authorized!'));
        }
        if (((_c = req.user) === null || _c === void 0 ? void 0 : _c.role) === 'admin') {
            next();
        }
        else {
            return next(new errors_1.ForbiddenError('You are not authorized!'));
        }
    });
};
exports.verifyAdmin = verifyAdmin;
//# sourceMappingURL=verify.js.map